Learn R Programming

MatchThem (version 0.8.1)

osteoarthritis: Data of 2,585 Participants in the OAI Project

Description

The dataset osteoarthritis includes demographic data of 2,585 observations (individuals) with or at risk of knee osteoarthritis. The recorded data has missing values in body mass index (BMI, a quantitative variable), race (RAC, a categorical qualitative variable), smoking status (SMK, a binary qualitative variable), osteoporosis status (OSP, a binary qualitative variable), and knee osteoarthritis status (KOA, a binary qualitative variable).

Usage

osteoarthritis

Arguments

Format

This dataset contains 2,585 rows and 7 columns. Each row presents data of an observation (individual) and each column presents data of a characteristics of that observation. The columns are:

AGE

Age of each observation (individual);

SEX

Gender of each observation (individual), coded as 0 (female) and 1 (male);

BMI

Estimated body mass index of each observation (individual);

RAC

Race of each observation (individual), coded as 0 (Other), 1 (Caucasian), 2 (African American), and 3 (Asian);

SMK

The smoking status of each observation, coded as 0 (non-smoker) and 1 (smoker)

OSP

Osteoporosis status of each observation (individual) at baseline, coded as 0 (negative) and 1 (positive); and

KOA

Knee osteoarthritis status of each observation (individual) in the follow-up, coded as 0 (at risk) and 1 (diagnosed).